import numpy as np
import matplotlib.pyplot as plt
import os

from skimage import data, io
from skimage.feature import match_template

folder_path = 'source'

images = {}
hierogliphs_in_line = {}

for filename in os.listdir(folder_path):
    if filename.endswith(".PNG"):
        file_path = os.path.join(folder_path, filename)
        
        image = io.imread(file_path)
        image = image[:, :, 0]
        name = filename
        last_dot_index = name.rfind(".")
        name = name[:last_dot_index]
        images[name] = image

image = io.imread('inscription.PNG')
image = image[:, :, 0]

for element in images:
    result = match_template(image, images[element])
    ij = np.unravel_index(np.argmax(result), result.shape)
    hierogliphs_in_line[ij[1]] = element
    x, y = ij[::-1]

sorted_items = sorted(hierogliphs_in_line.items(), key=lambda x: x[0])
print("These hieroglyphs mean: ", end="")
for element in sorted_items:
    print(element[1], end="")
    result = match_template(image, images[element[1]])
    ij = np.unravel_index(np.argmax(result), result.shape)
    x, y = ij[::-1]

    fig = plt.figure(figsize=(8, 3))
    ax1 = plt.subplot(1, 3, 1)
    ax2 = plt.subplot(1, 3, 2)
    ax3 = plt.subplot(1, 3, 3, sharex=ax2, sharey=ax2)

    ax1.imshow(images[element[1]], cmap=plt.cm.gray)
    ax1.set_axis_off()
    ax1.set_title('template')

    ax2.imshow(image, cmap=plt.cm.gray)
    ax2.set_axis_off()
    ax2.set_title('image')

    hcoin, wcoin = images[element[1]].shape
    rect = plt.Rectangle((x, y), wcoin, hcoin, edgecolor='r', facecolor='none')
    ax2.add_patch(rect)

    ax3.imshow(result)
    ax3.set_axis_off()
    ax3.set_title('`match_template`\nresult')

    ax3.autoscale(False)
    ax3.plot(x, y, 'o', markeredgecolor='r', markerfacecolor='none', markersize=10)
    plt.show()


    